nwbwidgets.dashboards package
=============================

Submodules
----------

nwbwidgets.dashboards.allen module
----------------------------------

.. automodule:: nwbwidgets.dashboards.allen
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: nwbwidgets.dashboards
   :members:
   :undoc-members:
   :show-inheritance:
